==> order-center-infrastructure-2.9.0-CLOUD-20220826.101751-7-sources.jar: com/tydic/dyc/oc/repository/po/UocOrderTaskInstLogPo.java <==
package com.tydic.dyc.oc.repository.po;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocOrderTaskInstLogPo
 * 说明:订单任务实例
 * 时间:2022-05-24 18:14
 * 作者:罗有
 **/
@Data
public class UocOrderTaskInstLogPo implements Serializable {
	private static final long serialVersionUID = 1430016678420840354L;

	@DocField(value = "id")
	private Long id;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "任务实例id")
	private String taskInstId;

	@DocField(value = "单据id")
	private Long objId;

	@DocField(value = "流程实例id")
	private String procInstId;

	@DocField(value = "流程key定义")
	private String procDefId;

	@DocField(value = "单据类型:1订单   2.销售单   3.执行单   4.发货单   5.收货单   6.售后服务单  7.支付单  8验收单，9审批单   99.其他")
	private Integer objType;

	@DocField(value = "加签标识 0 ：环节任务   1：前加签任务  2：后加签任务  3：存在后加签任务")
	private Integer taskSignTag;

	@DocField(value = "所在环节")
	private String procState;

	@DocField(value = "表单url")
	private String formUrl;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "完结标志0未完结1已完结")
	private Integer finishTag;

	@DocField(value = "完成时间")
	private Date finishTime;

	@DocField(value = "完成时间 开始")
	private Date finishTimeStart;

	@DocField(value = "完成时间 结束")
	private Date finishTimeEnd;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;

}

==> order-center-infrastructure-3.0.0-CLOUD-20250527.111438-72-sources.jar: com/tydic/dyc/oc/repository/po/UocOrderTaskInstLogPo.java <==
package com.tydic.dyc.oc.repository.po;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocOrderTaskInstLogPo
 * 说明:订单任务实例
 * 时间:2022-05-24 18:14
 * 作者:罗有
 **/
@Data
public class UocOrderTaskInstLogPo implements Serializable {
	private static final long serialVersionUID = 1430016678420840354L;

	@DocField(value = "id")
	private Long id;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "任务实例id")
	private String taskInstId;

	@DocField(value = "单据id")
	private Long objId;

	@DocField(value = "流程实例id")
	private String procInstId;

	@DocField(value = "流程key定义")
	private String procDefId;

	@DocField(value = "单据类型:1订单   2.销售单   3.执行单   4.发货单   5.收货单   6.售后服务单  7.支付单  8验收单，9审批单   99.其他")
	private Integer objType;

	@DocField(value = "加签标识 0 ：环节任务   1：前加签任务  2：后加签任务  3：存在后加签任务")
	private Integer taskSignTag;

	@DocField(value = "所在环节")
	private String procState;

	@DocField(value = "表单url")
	private String formUrl;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "完结标志0未完结1已完结")
	private Integer finishTag;

	@DocField(value = "完成时间")
	private Date finishTime;

	@DocField(value = "完成时间 开始")
	private Date finishTimeStart;

	@DocField(value = "完成时间 结束")
	private Date finishTimeEnd;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

		@DocField(value = "排序")
	private String orderBy;

	@DocField(value = "租户id")
	private Long sysTenantId;

	@DocField(value = "租户名称")
	private String sysTenantName;

}
